@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20210331';
+our $VERSION = '0.20210430';
 
-# Table last modified: 2021-03-31
+# Table last modified: 2021-04-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -45,7 +45,7 @@ our %ZIP_TABLE = (
     '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|0(?:19[58]|[28]92|595)|11(?:9[237]|8[0159])|4(?:29[23]|495|692)|3393))',
     '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|1[0-2]|0[125]|6[017])|6(?:55|70|4[02]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
     '041' => '(?:(?:8(?:5(?:01|40|77|2[23]|8[89]|1[0-25]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
-    '042' => '(?:8(?:5(?:[01]1|67|8[58]|5[05])|6(?:39|42|78)))',
+    '042' => '(?:8(?:5(?:[01]1|55|67|8[58])|6(?:39|42|78)))',
     '043' => '(?:(?:8(?:5(?:58|60)|6(?:09|51))|0[45]95|1498))',
     '044' => '(?:(?:85(?:44|88)|029[256]))',
     '045' => '(?:8(?:555|609))',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|2[0-57-9]|6[16-8]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[15-7]|0[35-7])|406))',
+    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|2[0-57-9]|6[16-8]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[5-7]|0[35-7])|406))',
     '061' => '(?:(?:1(?:49[236-8]|39[2356]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68]|5[56])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -103,15 +103,15 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|1[01357-9]|3[0-69])|2(?:28|51|70|8[2358]|0[137]|3[2-5]|1[4-69]|4[16]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|66|8[06]|5[015]|7[07-9])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|1[01357-9]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[16]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|66|8[06]|5[015]|7[07-9])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[1-8]|3[013568]|1[013-7])|6(?:1[0-35-79]|8[28]|6[2578]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
-    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|9[0-4]|7[0-25-8]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-579])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|2[0146]|4[05]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
+    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|2[0146]|4[05]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|5[158]|1[014-8]|8[1389]|4[25]|3[0-589]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|3[02358]|4[0-5]|0[1-79])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|4[03489]|0[124-8]|8[168]|2[0-4679]|5[0156]|6[08]|1[05689])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:6[014589]|5[1-36-8]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9]|8[2-68])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|2[0136]|8[015689]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:20|39|55|0[1258]|7[07]|8[58]|1[01])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6050))',
+    '105' => '(?:(?:8(?:4(?:6[014589]|5[1-36-8]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9]|8[2-68])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|2[0136]|8[015689]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:20|39|55|0[1258]|7[07]|8[58]|1[01])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|7[23589]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|3[029]|1[014-7]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|7[23589]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:2[0-2568]|6[0259]|5[34]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|5[128]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|1[1256])|6(?:01|7[02578]|4[04]|3[0147]|6[013689]|2[13568]|5[03-68]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|8[1245]0))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:2[0-5]|1[1-689])|2(?:14|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:1[1-689]|2[0-6])|2(?:14|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
@@ -148,7 +148,7 @@ our %ZIP_TABLE = (
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
-    '158' => '(?:8(?:5(?:3[1349]|1[0-58]|8[0568]|5[0-2578]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
+    '158' => '(?:8(?:5(?:3[1349]|5[0-278]|1[0-58]|8[0568]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
     '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|0[14689]|[24][17]|1[169]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-378])|5(?:65|4[37]|1[0-259]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|(?:68|91)0|8(?:01|12)))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
@@ -190,19 +190,19 @@ our %ZIP_TABLE = (
     '201' => '(?:8(?:5(?:[01]1|8[58])|6(?:01|48|86)))',
     '202' => '(?:85(?:20|85|5[58]))',
     '203' => '(?:8(?:5(?:[12]1|55|8[58])|601|739))',
-    '204' => '(?:85(?:11|22|33|67|5[58]|8[589]))',
+    '204' => '(?:85(?:[01]1|22|33|67|5[58]|8[589]))',
     '205' => '(?:8(?:5(?:11|55|0[13])|6(?:60|0[1467])))',
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|1[0-25]|6[167]|0[235]|5[15])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
     '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
     '211' => '(?:8(?:5(?:[34]0|66|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
-    '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|0[2589]|8[1-59]|1[01])|602))',
+    '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|0[2589]|8[1-59]|1[01])|60[23]))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|8[016-9]|1[125-7]|3[35]|7[0367]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2]|3[689])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|22|39|65|5[05])|080|173|401))',
+    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|22|39|65|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:[58][058]|1[0-25]|2[0-35-7]|7[27]|6[067]|4[0-2]|0[125-8]|3[039]))',
@@ -215,7 +215,7 @@ our %ZIP_TABLE = (
     '232' => '(?:8(?:5(?:31|8[057]|5[58]|1[05])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
-    '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:5[13]|4[158])))',
+    '236' => '(?:8(?:5(?:15|40|0[1-4]|5[05])|6(?:5[13]|4[158])))',
     '237' => '(?:85(?:23|55|1[05]))',
     '238' => '(?:(?:8(?:5(?:70|8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|60|8[58]|5[08])|68[68]))',
@@ -240,7 +240,7 @@ our %ZIP_TABLE = (
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-46-8]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
     '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[12457-9]|8[0568]|0[1-35-9]|3[4-68]|6[0-467]|2[13478]|1[0-3568])|7(?:1[02357]|0[137]|2[02]|3[034])))',
-    '261' => '(?:8(?:5(?:4[45]|3[0359]|1[0235]|7[57]|5[0248]|0[1-478]|2[0-2]|6[68]|8[125-8])|6(?:09|86)|733))',
+    '261' => '(?:8(?:5(?:3[0359]|1[0235]|7[57]|5[0248]|0[1-478]|2[0-2]|6[68]|8[125-8]|4[145])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-2])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|66|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
@@ -251,7 +251,7 @@ our %ZIP_TABLE = (
     '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|019[35]))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|27)|7(?:10|33))|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
-    '275' => '(?:8(?:5(?:11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
+    '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
     '277' => '(?:8(?:5(?:6[14-69]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|2[0-2]|7[0-479])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|7[07]|5[05])|6(?:01|86)))',
@@ -292,7 +292,7 @@ our %ZIP_TABLE = (
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:[58]5|11)|60[12]))',
     '318' => '(?:85[01]1)',
-    '319' => '(?:(?:1(?:1(?:9[24-7]|8[48])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2692|3595))',
+    '319' => '(?:(?:1(?:1(?:9[24-7]|8[48])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|0[1-35-8]|8[058]|4[013]|7[07]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
     '321' => '(?:(?:3(?:29[235-8]|39[258]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[23]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
@@ -301,9 +301,9 @@ our %ZIP_TABLE = (
     '325' => '(?:039[23578])',
     '326' => '(?:(?:8(?:5(?:11|72|85|5[08]|2[01]|0[125])|6(?:[01]1|30|86))|039[25]))',
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
-    '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[568])|6(?:86|6[68]))|0192))',
+    '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:59[568]|49[28]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[238]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|6[4-6]|3[156]|7[57]|1[12]|8[0-368]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|6[24-6]|5[0-3]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:10|77))))',
+    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|6[24-6]|5[0-3]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:10|77))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|9(?:5(?:[1-35]0|77)|624)))',
     '332' => '(?:8(?:5(?:21|33|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
@@ -311,19 +311,19 @@ our %ZIP_TABLE = (
     '335' => '(?:8(?:5(?:10|22|33|[58][58]|0[12])|6(?:55|66)))',
     '336' => '(?:8(?:5(?:40|6[14]|1[25]|2[1-36]|8[67]|[05][58])|6(?:[36]6|55)|760))',
     '337' => '(?:85(?:[58]6|32|70|0[127]))',
-    '338' => '(?:8(?:5(?:8[056]|1[0-35]|2[3-5]|0[3-68]|6[67]|7[0157]|5[1578]|3[18]|4[01])|6(?:30|86)))',
+    '338' => '(?:8(?:5(?:8[056]|1[0-35]|2[3-5]|7[057]|0[3-68]|6[67]|5[1578]|3[18]|4[01])|6(?:30|86)))',
     '339' => '(?:8(?:5(?:[02]1|39|66|85|5[18]|1[01])|6(?:01|86)))',
     '340' => '(?:(?:8(?:5(?:33|77|5[015]|2[04]|0[19]|8[58]|6[078]|1[01])|6(?:59|86|1[01]))|0(?:19[2-4]|295)))',
     '341' => '(?:85(?:01|5[058]|2[67]))',
     '342' => '(?:8(?:50[125]|601))',
     '343' => '(?:(?:8(?:5(?:11|40|85|5[458]|0[12])|601)|019[23]))',
-    '344' => '(?:8(?:5(?:11|40|55|66|7[78]|3[35]|8[58]|2[12]|0[68])|686))',
+    '344' => '(?:8(?:5(?:11|40|55|66|7[78]|3[35]|8[58]|2[12]|0[68])|68[06]))',
     '345' => '(?:850[1248])',
     '346' => '(?:(?:8(?:5(?:[34]0|24|[01][16])|68[56])|01(?:8[13]|9[2-68])))',
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-6])|1(?:19[23]|292)))',
-    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[058]|9[258])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:92|8[0-278])))',
+    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[058]|9[258])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
     '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -344,7 +344,7 @@ our %ZIP_TABLE = (
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
     '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
     '370' => '(?:(?:8(?:5(?:[01]1|[68]5|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
-    '371' => '(?:(?:8(?:5(?:5[05-7]|8[056]|0[1-578]|1[0-7]|2[0-2578]|4[38]|3[01359]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
+    '371' => '(?:(?:8(?:5(?:[58][05-7]|0[1-578]|1[0-7]|2[0-2578]|4[38]|3[01359]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
     '372' => '(?:8(?:5(?:10|58|67|8[058]|0[128])|686))',
     '373' => '(?:8(?:5(?:21|78|1[0-35]|0[1589]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[068]|8[68]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
@@ -357,7 +357,7 @@ our %ZIP_TABLE = (
     '381' => '(?:(?:8(?:5(?:1[015]|5[0168]|[67][07]|3[09]|0[138]|4[58]|2[05]|8[08])|6(?:02|86)|793)|0(?:2(?:88|9[235-8])|19[23]|49[78])|22(?:8[0-35-9]|9[258])|4(?:19[23]|393)))',
     '382' => '(?:8(?:5(?:33|55|77|0[1258]|8[578]|1[0-2])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
-    '384' => '(?:(?:8(?:5(?:01|58|8[58])|605)|0(?:69[2578]|393|798)|(?:11|22)92))',
+    '384' => '(?:(?:8(?:5(?:[01]1|58|8[58])|605)|0(?:69[2578]|393|798)|(?:11|22)92))',
     '385' => '(?:8(?:5(?:[01]1|22|33|8[568]|5[58])|6(?:[01]1|86)))',
     '386' => '(?:(?:8(?:5(?:[67]7|22|43|5[135]|8[458]|1[01]|0[15])|6(?:24|0[189]|8[3568]|6[68]|3[48]|1[01])|7(?:05|20|1[05]))|0(?:49[23578]|39[36]|[15]92)|1(?:19[23]|298)|2292))',
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
@@ -566,13 +566,13 @@ our %ZIP_TABLE = (
     '597' => '(?:8(?:5(?:22|55|8[58]|0[12]|1[15])|686))',
     '598' => '(?:85(?:[13]1|22|40|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
-    '600' => '(?:8(?:5(?:44|3[03]|2[056]|6[5-7]|1[19]|5[058]|8[1568]|0[1-356]|7[07])|6(?:52|65|8[68])|7(?:11|87)))',
+    '600' => '(?:8(?:5(?:44|3[03]|2[056]|6[5-7]|1[19]|5[058]|8[1568]|0[1-356]|7[07])|6(?:52|65|8[68])|7(?:11|87|92)))',
     '601' => '(?:(?:8(?:5(?:[26]0|42|88|3[03]|5[09]|0[126]|1[01])|601)|1(?:192|397|495)|0(?:292|797)))',
     '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|611))',
     '603' => '(?:85(?:11|22|55|77|88))',
     '604' => '(?:8(?:5(?:[24]0|1[015]|0[1258]|8[058]|7[178]|6[07]|5[01568])|666|798))',
     '605' => '(?:8(?:5(?:11|0[15])|686))',
-    '606' => '(?:8(?:5(?:11|22|36|40|[58][58]|0[1257])|792))',
+    '606' => '(?:85(?:11|22|36|40|[58][58]|0[1257]))',
     '607' => '(?:85[017]1)',
     '610' => '(?:(?:0(?:3(?:80|9[3-7])|19[256]|28[179])|119[2578]))',
     '611' => '(?:8(?:5(?:[58]5|01)|660))',
@@ -729,7 +729,7 @@ our %ZIP_TABLE = (
     '768' => '(?:(?:019[25]|860[12]))',
     '769' => '(?:(?:2(?:7(?:88|9[2-7])|69[2356]|19[235]|39[56]|[49]92)|0(?:19[2-578]|29[2356])|1(?:69[568]|192|593)))',
     '770' => '(?:8(?:5(?:7[0-3]|5[0-258]|0[1-9]|1[0-68]|3[0-35-9]|2[0-689]|4[0146-8]|8[58]|6[0357])|6(?:10|48|0[15])|7(?:87|9[48])))',
-    '771' => '(?:(?:0(?:2(?:8[1-57-9]|9[2-68])|1(?:8[235-9]|9[2-68]))|1(?:2(?:89|9[24578])|49[2-48]|[357]92|19[23]|695)|(?:33|2[135]|4[13]|5[24])95|6(?:192|495)))',
+    '771' => '(?:(?:0(?:1(?:9[2-8]|8[235-9])|2(?:8[1-57-9]|9[2-68]))|1(?:2(?:89|9[24578])|49[2-48]|[357]92|19[23]|695)|(?:33|2[135]|4[13]|5[24])95|6(?:192|495)))',
     '772' => '(?:8(?:5(?:20|1[015]|0[1-3])|601))',
     '773' => '(?:8(?:50[124]|601))',
     '774' => '(?:8[56]01)',
@@ -739,7 +739,7 @@ our %ZIP_TABLE = (
     '778' => '(?:(?:850[13-7]|0[12]95))',
     '779' => '(?:(?:3(?:39[3-5]|[4-6]95|29[58])|4(?:[478]95|19[35])|1(?:29[235]|195)|(?:53|2[13])95|019[2-5]))',
     '780' => '(?:8(?:5(?:3[024-69]|0[1-47-9]|4[0145]|5[03-589]|1[024-7]|2[0278]|6[125-8]|7[0-27])|6(?:86|7[067]|0[125]|6[0-3568])|787))',
-    '781' => '(?:(?:9(?:5(?:[05]6|48|3[378]|2[1569]|1[139])|68[3-9])|85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
+    '781' => '(?:(?:9(?:5(?:[05]6|48|3[378]|2[569]|1[139])|68[3-9])|85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
     '782' => '(?:8502)',
     '783' => '(?:85(?:[58]5|10|0[125-9]))',
     '784' => '(?:850[135])',
@@ -866,7 +866,7 @@ our %ZIP_TABLE = (
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:8(?:5(?:01|50)|601)|0[256]92))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
-    '910' => '(?:(?:8(?:5(?:3[0235-9]|8\d|4[013-58]|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|3[56])92|419[35-8]))',
+    '910' => '(?:(?:8(?:5(?:3[0235-9]|4[0-58]|[28]\d|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|3[56])92|419[35-8]))',
     '911' => '(?:8(?:5(?:[03]1|[14]0|85|5[58])|601))',
     '912' => '(?:(?:8(?:5(?:[58]5|24|40|67)|6[68]6)|0292))',
     '913' => '(?:8(?:5(?:[01]1|33|55|77|8[58])|611))',
@@ -874,10 +874,10 @@ our %ZIP_TABLE = (
     '915' => '(?:(?:8(?:5(?:01|55|3[03]|2[04]|8[568]|1[01])|666)|0292|1195))',
     '916' => '(?:(?:8(?:5(?:67|5[058]|8[58]|1[05]|0[1578])|6(?:[468]6|01))|0(?:29[235]|[14]92)|1198))',
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
-    '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|8[03568]|0[1-3589])|6(?:68|8[168])))',
+    '918' => '(?:8(?:5(?:4[03]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
-    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|1[0-35-8]|7[0357]|5[0-8]|[68][035-8])|6(?:8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69]|2[0-3568])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
-    '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|50|3[079]|1[126]|2[01])|798))',
+    '920' => '(?:(?:8(?:5(?:4[0134]|2[0-25]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69]|2[0-3568])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
+    '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|4[14-6]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]))',
